@@ -31,6 +31,7 @@
 #include <sys/wait.h>
 #include <strings.h>
 #include <signal.h>
+#include <syslog.h>
 #include <errno.h>
 #include <time.h>
 #include <X11/Xlib.h>
@@ -60,10 +61,10 @@ extern gchar *GdmServAuthDir;
 extern gchar *GdmLogDir;
 extern gchar *GdmStandardXServer;
 extern gboolean GdmXdmcp;
-extern sigset_t sysmask;
 extern gint high_display_num;
 extern pid_t extra_process;
 extern int extra_status;
+extern int gdm_in_signal;
 
 /* Global vars */
 static GdmDisplay *d = NULL;
@@ -666,6 +667,8 @@ gdm_server_spawn (GdmDisplay *d)
 	if (GdmXdmcp)
 		gdm_xdmcp_close();
 
+	closelog ();
+
 	/* close things */
 	for (i = 0; i < sysconf (_SC_OPEN_MAX); i++)
 		close(i);
@@ -676,6 +679,8 @@ gdm_server_spawn (GdmDisplay *d)
 	open ("/dev/null", O_RDWR); /* open stdout - fd 1 */
 	open ("/dev/null", O_RDWR); /* open stderr - fd 2 */
 
+	openlog ("gdm", LOG_PID, LOG_DAEMON);
+
 	/* Rotate the X server logs */
 	rotate_logs (d->name);
 
@@ -723,14 +728,10 @@ gdm_server_spawn (GdmDisplay *d)
 		_exit (SERVER_ABORT);
 	}
 
-	/* unblock HUP/TERM/USR1 so that we can control the
-	 * X server */
-	sigprocmask (SIG_SETMASK, &sysmask, NULL);
+	/* unblock signals (especially HUP/TERM/USR1) so that we
+	 * can control the X server */
 	sigemptyset (&mask);
-	sigaddset (&mask, SIGUSR1);
-	sigaddset (&mask, SIGHUP);
-	sigaddset (&mask, SIGTERM);
-	sigprocmask (SIG_UNBLOCK, &mask, NULL);
+	sigprocmask (SIG_SETMASK, &mask, NULL);
 
 	if (d->type == TYPE_FLEXI_XNEST) {
 		gnome_setenv ("DISPLAY", d->xnest_disp, TRUE);
@@ -878,6 +879,8 @@ gdm_server_spawn (GdmDisplay *d)
 static void
 gdm_server_usr1_handler (gint sig)
 {
+    gdm_in_signal++;
+
     d->servstat = SERVER_RUNNING; /* Server ready to accept connections */
     d->starttime = time (NULL);
 
@@ -886,6 +889,8 @@ gdm_server_usr1_handler (gint sig)
     server_signal_notified = TRUE;
     /* this will quit the select */
     write (server_signal_pipe[1], "Yay!", 4);
+
+    gdm_in_signal--;
 }
 
 
@@ -899,6 +904,8 @@ gdm_server_usr1_handler (gint sig)
 static void 
 gdm_server_alarm_handler (gint signal)
 {
+    gdm_in_signal++;
+
     d->servstat = SERVER_TIMEOUT; /* Server didn't start */
 
     gdm_debug ("gdm_server_alarm_handler: Got SIGALRM, server abort");
@@ -906,6 +913,8 @@ gdm_server_alarm_handler (gint signal)
     server_signal_notified = TRUE;
     /* this will quit the select */
     write (server_signal_pipe[1], "Yay!", 4);
+
+    gdm_in_signal--;
 }
 
 
@@ -922,6 +931,8 @@ gdm_server_child_handler (int signal)
 	int status;
 	pid_t pid;
 
+	gdm_in_signal++;
+
 	gdm_debug ("gdm_server_child_handler: Got SIGCHLD");
 
 	while ((pid = waitpid (-1, &status, WNOHANG)) > 0) {
@@ -950,6 +961,8 @@ gdm_server_child_handler (int signal)
 			extra_status = status;
 		}
 	}
+
+	gdm_in_signal--;
 }
 
 
@@ -968,7 +981,7 @@ gdm_server_alloc (gint id, const gchar *command)
     GdmDisplay *d;
     
     if (gethostname (hostname, 1023) == -1)
-	return NULL;
+	    strcmp (hostname, "localhost.localdomain");
 
     d = g_new0 (GdmDisplay, 1);
 
@@ -1009,6 +1022,9 @@ gdm_server_alloc (gint id, const gchar *command)
     d->login = NULL;
 
     d->timed_login_ok = FALSE;
+
+    d->slave_notify_fd = -1;
+    d->master_notify_fd = -1;
     
     return d;
 }
